@@ -38,7 +38,6 @@
 
 OdrsReviewsBackend::OdrsReviewsBackend()
     : AbstractReviewsBackend(nullptr)
-    , m_isFetching(false)
 {
     bool fetchRatings = false;
     const QUrl ratingsUrl(QStringLiteral(APIURL "/ratings"));
@@ -59,7 +58,7 @@ OdrsReviewsBackend::OdrsReviewsBackend()
     }
 
     if (fetchRatings) {
-        m_isFetching = true;
+        setFetching(true);
         KIO::FileCopyJob *getJob = KIO::file_copy(ratingsUrl, fileUrl, -1, KIO::Overwrite | KIO::HideProgressInfo);
         connect(getJob, &KIO::FileCopyJob::result, this, &OdrsReviewsBackend::ratingsFetched);
     } else {
@@ -72,9 +71,18 @@ OdrsReviewsBackend::~OdrsReviewsBackend() noexcept
     qDeleteAll(m_ratings);
 }
 
+void OdrsReviewsBackend::setFetching(bool fetching)
+{
+    if (fetching == m_isFetching) {
+        return;
+    }
+    m_isFetching = fetching;
+    Q_EMIT fetchingChanged(fetching);
+}
+
 void OdrsReviewsBackend::ratingsFetched(KJob *job)
 {
-    m_isFetching = false;
+    setFetching(false);
     if (job->error()) {
         qCWarning(LIBDISCOVER_LOG) << "Failed to fetch ratings " << job->errorString();
     } else {
@@ -106,14 +114,21 @@ static QString userHash()
 
 void OdrsReviewsBackend::fetchReviews(AbstractResource *app, int page)
 {
+    if (app->appstreamId().isEmpty()) {
+        return;
+    }
     Q_UNUSED(page)
-    m_isFetching = true;
+    const QString version = app->isInstalled() ? app->installedVersion() : app->availableVersion();
+    if (version.isEmpty()) {
+        return;
+    }
+    setFetching(true);
 
     const QJsonDocument document(QJsonObject{
         {QStringLiteral("app_id"), app->appstreamId()},
         {QStringLiteral("distro"), osName()},
         {QStringLiteral("user_hash"), userHash()},
-        {QStringLiteral("version"), app->isInstalled() ? app->installedVersion() : app->availableVersion()},
+        {QStringLiteral("version"), version},
         {QStringLiteral("locale"), QLocale::system().name()},
         {QStringLiteral("limit"), -1},
     });
@@ -138,7 +153,7 @@ void OdrsReviewsBackend::reviewsFetched()
     if (networkError != QNetworkReply::NoError) {
         qCWarning(LIBDISCOVER_LOG) << "error fetching reviews:" << reply->errorString() << data;
         Q_EMIT error(i18n("Error while fetching reviews: %1", reply->errorString()));
-        m_isFetching = false;
+        setFetching(false);
         return;
     }
 
@@ -193,7 +208,7 @@ QString OdrsReviewsBackend::userName() const
     return KUser().property(KUser::FullName).toString();
 }
 
-void OdrsReviewsBackend::submitReview(AbstractResource *res, const QString &summary, const QString &description, const QString &rating)
+void OdrsReviewsBackend::sendReview(AbstractResource *res, const QString &summary, const QString &description, const QString &rating, const QString &userName)
 {
     Q_ASSERT(res);
     QJsonObject map = {
@@ -203,7 +218,7 @@ void OdrsReviewsBackend::submitReview(AbstractResource *res, const QString &summ
         {QStringLiteral("version"), res->isInstalled() ? res->installedVersion() : res->availableVersion()},
         {QStringLiteral("locale"), QLocale::system().name()},
         {QStringLiteral("distro"), osName()},
-        {QStringLiteral("user_display"), QJsonValue::fromVariant(KUser().property(KUser::FullName))},
+        {QStringLiteral("user_display"), QJsonValue::fromVariant(userName)},
         {QStringLiteral("summary"), summary},
         {QStringLiteral("description"), description},
         {QStringLiteral("rating"), rating.toInt() * 10},
@@ -283,7 +298,7 @@ void OdrsReviewsBackend::parseRatings()
 
 void OdrsReviewsBackend::parseReviews(const QJsonDocument &document, AbstractResource *resource)
 {
-    m_isFetching = false;
+    setFetching(false);
     Q_ASSERT(resource);
     if (!resource) {
         return;
