@@ -56,7 +56,8 @@ void DummyReviewsBackend::initialize()
 {
     int i = 11;
     DummyBackend *b = qobject_cast<DummyBackend *>(parent());
-    foreach (DummyResource *app, b->resources()) {
+    const auto resources = b->resources();
+    for (DummyResource *app : resources) {
         if (m_ratings.contains(app))
             continue;
         auto randomRating = qrand() % 10;
@@ -75,9 +76,9 @@ void DummyReviewsBackend::submitUsefulness(Review *r, bool useful)
     r->setUsefulChoice(useful ? ReviewsModel::Yes : ReviewsModel::No);
 }
 
-void DummyReviewsBackend::submitReview(AbstractResource *res, const QString &a, const QString &b, const QString &c)
+void DummyReviewsBackend::sendReview(AbstractResource *res, const QString &a, const QString &b, const QString &c, const QString &d)
 {
-    qDebug() << "dummy submit review" << res->name() << a << b << c;
+    qDebug() << "dummy submit review" << res->name() << a << b << c << d;
 }
 
 bool DummyReviewsBackend::isResourceSupported(AbstractResource * /*res*/) const
