@@ -10,6 +10,7 @@
 #include "PackageKitResource.h"
 #include <AppStreamQt/pool.h>
 #include <PackageKit/Transaction>
+#include <QFile>
 #include <QPointer>
 #include <QSet>
 #include <QSharedPointer>
@@ -46,13 +47,13 @@ public:
     Transaction *removeApplication(AbstractResource *app) override;
     bool isValid() const override
     {
-        return true;
+        return !QFile::exists(QStringLiteral("/run/ostree-booted"));
     }
     QSet<AbstractResource *> upgradeablePackages() const;
     bool isFetching() const override;
 
     bool isPackageNameUpgradeable(const PackageKitResource *res) const;
-    QString upgradeablePackageId(const PackageKitResource *res) const;
+    QSet<QString> upgradeablePackageId(const PackageKitResource *res) const;
     QVector<AppPackageKitResource *> extendedBy(const QString &id) const;
 
     void resolvePackages(const QStringList &packageNames);
@@ -75,6 +76,8 @@ public:
     void fetchUpdates();
     int fetchingUpdatesProgress() const override;
 
+    HelpfulError *explainDysfunction() const override;
+
     void addPackageArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
     void addPackageNotArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
 
